==> synhelper-8.x-1.51.tar.gz: synhelper/src/Service/ParagraphImport.php <==
<?php

namespace Drupal\synhelper\Service;

/**
 * ParagraphImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class ParagraphImport implements ContentImportInterface {

  /**
   * Controller constructor.
   */
  public function __construct() {

  }

  /**
   * Import Paragraph(about && image_blocks && Параметры).
   *
   * If needed more just copy one of them and set your fields.
   */
  public static function import($field_paragraph) : array {
    $storage = \Drupal::service('entity_type.manager')->getStorage('paragraph');
    /* Importing About Us */
    if (!empty($field_paragraph['about'])) {
      $items = [];
      $about = $field_paragraph['about'];
      foreach ($about['field_about_items'] as $about_item) {
        $item = $storage->create($about_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $about_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $about_item['field_title'],
          'field_description' => $about_item['field_description'],
        ];
      }
      $about['field_about_items'] = $items;
      $paragraph = $storage->create($about);
      $paragraph->save();
      $paragraphs = [];
      $paragraphs[] = [
        'type' => $about['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Image Blocks */
    if (!empty($field_paragraph['image_blocks'])) {
      $items = [];
      $imageBloсks = $field_paragraph['image_blocks'];
      foreach ($imageBloсks['field_image_blocks_items'] as $image_blocks_item) {
        $image_blocks_item['field_image'] = FilesImport::importImages($image_blocks_item['field_image']);
        $item = $storage->create($image_blocks_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $image_blocks_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $image_blocks_item['field_title'],
          'field_body' => $image_blocks_item['field_body'],
          'field_image_text_sort' => $image_blocks_item['field_image_text_sort'],
        ];
      }
      $imageBloсks['field_image_blocks_items'] = $items;
      $paragraph = $storage->create($imageBloсks);
      $paragraph->save();

      $paragraphs[] = [
        'type' => $imageBloсks['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Параметры */
    if (!empty($field_paragraph['product_param'])) {
      foreach ($field_paragraph['product_param'] as $param) {
        $t = [
          'uid' => 1,
          'type' => $param['type'],
          'field_product_param_param' => $param['field_product_param_param'],
          'field_product_param_value' => $param['field_product_param_value'],
        ];
        $paragraph = $storage->create($t);
        $paragraph->save();
        $paragraphs[] = [
          'type' => 'product_param',
          'target_id' => $paragraph->id(),
          'target_revision_id' => $paragraph->getRevisionId(),
        ];
      }
    }
    return $paragraphs;
  }

}

==> synhelper-8.x-1.65.tar.gz: synhelper/src/Service/ParagraphImport.php <==
<?php

namespace Drupal\synhelper\Service;

/**
 * ParagraphImport class.
 *
 * @internal
 *   For internal usage by the Commerce synhelper module.
 */
class ParagraphImport implements ContentImportInterface {
  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\FilesImport
   */
  protected $filesImport;

  /**
   * Service for service.
   *
   * @var Drupal\synhelper\Service\TaxonomyImport
   */

  protected $taxonomyImport;

  /**
   * Controller constructor.
   */
  public function __construct(ContentImportInterface $filesImport, ContentImportInterface $taxonomyImport) {
    $this->filesImport = $filesImport;
    $this->taxonomyImport = $taxonomyImport;
  }

  /**
   * Import Paragraph(about && image_blocks && Параметры).
   *
   * If needed more just copy one of them and set your fields.
   */
  public function import($field_paragraph) : array {
    $storage = \Drupal::service('entity_type.manager')->getStorage('paragraph');
    /* Importing About Us */
    if (!empty($field_paragraph['about'])) {
      $items = [];
      $about = $field_paragraph['about'];
      foreach ($about['field_about_items'] as $about_item) {
        $item = $storage->create($about_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $about_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $about_item['field_title'],
          'field_description' => $about_item['field_description'],
        ];
      }
      $about['field_about_items'] = $items;
      $paragraph = $storage->create($about);
      $paragraph->save();
      $paragraphs = [];
      $paragraphs[] = [
        'type' => $about['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Image Blocks */
    if (!empty($field_paragraph['image_blocks'])) {
      $items = [];
      $imageBloсks = $field_paragraph['image_blocks'];
      foreach ($imageBloсks['field_image_blocks_items'] as $image_blocks_item) {
        $image_blocks_item['field_image'] = $this->filesImport->importImages($image_blocks_item['field_image']);
        $item = $storage->create($image_blocks_item);
        $item->save();
        $items[] = [
          'uid' => 1,
          'type' => $image_blocks_item['type'],
          'target_id' => $item->id(),
          'target_revision_id' => $item->getRevisionId(),
          'field_title' => $image_blocks_item['field_title'],
          'field_body' => $image_blocks_item['field_body'],
          'field_image_text_sort' => $image_blocks_item['field_image_text_sort'],
        ];
      }
      $imageBloсks['field_image_blocks_items'] = $items;
      $paragraph = $storage->create($imageBloсks);
      $paragraph->save();

      $paragraphs[] = [
        'type' => $imageBloсks['type'],
        'target_id' => $paragraph->id(),
        'target_revision_id' => $paragraph->getRevisionId(),
      ];
    }

    /* Importing Параметры */
    if (!empty($field_paragraph['product_param'])) {
      foreach ($field_paragraph['product_param'] as $param) {
        $t = [
          'uid' => 1,
          'type' => $param['type'],
          'field_product_param_param' => $param['field_product_param_param'],
          'field_product_param_value' => $param['field_product_param_value'],
        ];
        $paragraph = $storage->create($t);
        $paragraph->save();
        $paragraphs[] = [
          'type' => 'product_param',
          'target_id' => $paragraph->id(),
          'target_revision_id' => $paragraph->getRevisionId(),
        ];
      }
    }
    return $paragraphs;
  }

}
